<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Admin;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;
use App\Validators\AuthValidator;
use Illuminate\Support\Facades\Hash;
use App\Managers\Team\TeamManager;
use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use App\Validators\Admin\AdminTeamValidator;
use App\Managers\Schedule\ScheduleManager;
use App\Managers\PlayerRatingSubstitute\PlayerRatingSubstituteManager;
use App\Managers\PlayerRatingsVotes\PlayerRatingsVotesManager;
use App\Managers\SchedulePreMatchFormation\SchedulePreMatchFormationManager;
use App\Managers\TacticContainer\TacticContainerManager;
use App\Managers\Tactics\TacticsManager;
use App\Managers\SchedulePlayers\SchedulePlayersManager;

class AdminTeamController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->teamValidator = new AdminTeamValidator();
        $this->teamManager = new TeamManager();
        $this->schedule = new ScheduleManager();
        $this->playerRatingSubstituteManager = new PlayerRatingSubstituteManager();
        $this->playerRatingsVotesManager = new PlayerRatingsVotesManager();
        $this->schedulePreMatchFormationManager = new SchedulePreMatchFormationManager();
        $this->tacticContainerManager = new TacticContainerManager();
        $this->tacticsManager = new TacticsManager();
        $this->schedulePlayersManager = new SchedulePlayersManager();
    }
    
    public function add()
    {
        return view('/admin/team/add');
    }
    
    public function save(Request $request)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'create');
        
        $validation = $this->teamValidator->add($data);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->teamManager->add($data);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Team Saved Successfully'], 200);
    }
    
    public function index()
    {
        $teams = $this->teamManager->get();
        return view('/admin/team/list')->with('teams', $teams);
    }
    
    public function edit($UUID)
    {
        return view('/admin/team/edit')->with('UUID', $UUID);
    }
    
    public function currentTeam($UUID)
    {
        $team = $this->teamManager->where('UUID', $UUID)->first()->toArray();
        return response()->json($team,200);
    }
    
    public function update(Request $request, $UUID)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'update');
        
        $validation = $this->teamValidator->update($data, $UUID);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->teamManager->updateData($data, $UUID);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Team Updated Successfully'], 200);
    }
    
    public function delete($UUID)
    {
        if(!$team = $this->teamManager->where('UUID', $UUID)->first())
        {
            return response()->json(['Team Not Found'], 404);
        }
        $schedules = $this->schedule->where('opposite_team', $UUID)->get();
        if ($schedules->isNotEmpty()) {
            $schedules = $this->schedule->where('opposite_team', $UUID)->get();
            
            if(!empty($schedules))
            {
                foreach($schedules AS $schedule)
                {
                    $scheduleID = $schedule['UUID'];
                    $this->playerRatingSubstituteManager->where('scheduled_id', $scheduleID)->delete();
                    $this->playerRatingsVotesManager->where('schedule_id', $scheduleID)->delete();
                    $this->schedulePreMatchFormationManager->where('schedule_id', $scheduleID)->delete();
                    $tacticContainers = $this->tacticContainerManager->where('schedule_id', $scheduleID)->get();
                    if(!empty($tacticContainers))
                    {
                        foreach($tacticContainers AS $tacticContainer)
                        {
                            $tacticContainerID = $tacticContainer['UUID'];
                            $this->tacticsManager->where('tactic_container_id', $tacticContainerID)->delete();
                        }
                    }
                    
                    $this->tacticContainerManager->where('schedule_id', $scheduleID)->delete();
                    $this->schedulePlayersManager->where('schedule_id', $scheduleID)->delete();
                }
            }
            
            $this->schedule->where('opposite_team', $UUID)->delete();
//            $message = '<b>The team ' . $team['name'] . ' is associated with the following schedules . You will have to delete the reference to ' . $team['name'] . ' from these Schedules before you delete this team.</b>';
//            $message.= "<ul>";
//            foreach($schedules AS $column)
//            {
//                $message.= "<li>" . $column->name . "</li>";
//            }
//            $message.= "</ul>";
//            
//            return response()->json([$message], 400);
//            exit;
        }
        $delete = $this->teamManager->deleteData($UUID);
        if(!$delete)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Team Deleted Successfully'], 200);
    }
}